@@ -60,7 +60,7 @@ setMethodS3("findUnitsTodo", "FirmaFile", function(this, units=NULL, ..., force=
 
   # Read pixels from each unit
   verbose && enter(verbose, "Reading data for these ", length(units), " units");
-#  value <- readCelUnits(getPathname(this), units=units, readIntensities=FALSE,
+#  value <- .readCelUnits(getPathname(this), units=units, readIntensities=FALSE,
 #                        readStdvs=FALSE, readPixels=TRUE, dropArrayDim=TRUE);
 
   value <- readUnits(this, units=units, readIntensities=FALSE,
@@ -253,7 +253,7 @@ setMethodS3("fromDataFile", "FirmaFile", function(static, df=NULL, filename=spri
     cdfHeader <- getHeader(cdf);
 
     # Build a valid CEL header
-    celHeader <- cdfHeaderToCelHeader(cdfHeader, sampleName=name);
+    celHeader <- .cdfHeaderToCelHeader(cdfHeader, sampleName=name);
 
     # Add some extra information about what the CEL file is for
     params <- c(Description="This CEL file contains FIRMA results calculated by the aroma.affymetrix package.");
@@ -270,7 +270,7 @@ setMethodS3("fromDataFile", "FirmaFile", function(static, df=NULL, filename=spri
     pathnameT <- pushTemporaryFile(pathname, verbose=verbose);
 
     # Create the CEL file
-    createCel(pathnameT, header=celHeader, ..., verbose=less(verbose));
+    .createCel(pathnameT, header=celHeader, ..., verbose=less(verbose));
 
     # Rename temporary file
     pathname <- popTemporaryFile(pathnameT, verbose=verbose);
@@ -336,8 +336,8 @@ setMethodS3("getUnitGroupCellMap", "FirmaFile", function(this, units=NULL, ...,
 
   unitNames <- names(cells);
 # BUG!  Fix this in ChipEffectFile.R
-#  unitSizes <- unlist(base::lapply(cells, FUN=length), use.names=FALSE);
-  unitSizes <- unlist(base::lapply(cells, FUN=function(unit){
+#  unitSizes <- unlist(lapply(cells, FUN=length), use.names=FALSE);
+  unitSizes <- unlist(lapply(cells, FUN=function(unit){
     length(.subset2(unit,"groups"));
   }), use.names=FALSE);
   cells <- unlist(cells, use.names=FALSE);
@@ -448,7 +448,7 @@ setMethodS3("updateDataFlat", "FirmaFile", function(this, data, ..., verbose=FAL
   data <- data[,keep];
   pathname <- getPathname(this);
   pathname <- Arguments$getWritablePathname(pathname):
-  updateCel(pathname, indices=indices, data, verbose=verbose2);
+  .updateCel(pathname, indices=indices, data, verbose=verbose2);
   verbose && exit(verbose);
 
   verbose && exit(verbose);
