@@ -3,13 +3,16 @@ setMethodS3("calculateWeights", "ProbeLevelModel", function(this, units=NULL, ra
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Local functions
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+  # Lookup MASS::psi.huber() once; '::' is expensive
+  MASS_psi.huber <- MASS::psi.huber;
+
   resFcn <- function(unit) {
     nbrOfGroups <- length(unit);
-    res <- base::lapply(1:nbrOfGroups, FUN=function(gg) {
+    res <- lapply(1:nbrOfGroups, FUN=function(gg) {
       y <- .subset2(.subset2(unit, gg), "eps");
       y <- log2(y);
       mad <- 1.4826 * median(abs(y));
-      matrix(MASS::psi.huber(y/mad), ncol=ncol(y));
+      matrix(MASS_psi.huber(y/mad), ncol=ncol(y));
     })
     res;
   } # resFcn()
@@ -72,7 +75,7 @@ setMethodS3("calculateWeights", "ProbeLevelModel", function(this, units=NULL, ra
     residualsList <- readUnits(rs, units=units, verbose=less(verbose), stratifyBy="pm");
 
     verbose && enter(verbose, "Calculating weights");
-    weightsList <- base::lapply(residualsList, FUN=resFcn);
+    weightsList <- lapply(residualsList, FUN=resFcn);
     verbose && exit(verbose);
 
     verbose && enter(verbose, "Storing weights");
@@ -80,12 +83,12 @@ setMethodS3("calculateWeights", "ProbeLevelModel", function(this, units=NULL, ra
     cdf <- getCellIndices(getCdf(ds), units=units, stratifyBy="pm", ...);
 
     for (ii in seq_along(ds)) {
-      wf <- getFile(ws, ii);
+      wf <- ws[[ii]];
 
       verbose && enter(verbose, sprintf("Array #%d ('%s') of %d", ii, getName(wf), length(ds)));
 
-      data <- base::lapply(weightsList, FUN=function(unit) {
-        base::lapply(unit, FUN=function(group) {
+      data <- lapply(weightsList, FUN=function(unit) {
+        lapply(unit, FUN=function(group) {
           nrow <- nrow(group);
           list(
             intensities=2^group[,ii],
@@ -95,7 +98,7 @@ setMethodS3("calculateWeights", "ProbeLevelModel", function(this, units=NULL, ra
         });
       });
 
-      updateCelUnits(getPathname(wf), cdf=cdf, data=data);
+      .updateCelUnits(getPathname(wf), cdf=cdf, data=data);
 
       verbose && exit(verbose);
     } # for (ii ...)
