@@ -98,8 +98,8 @@ setMethodS3("fitOneArray", "SingleArrayUnitModel", function(this, array="remaini
 
   ces <- getChipEffectSet(this);
 
-  df <- getFile(ds, array);
-  cef <- getFile(ces, array);
+  df <- ds[[array]];
+  cef <- ces[[array]];
 
   # Sanity check
   stopifnot(identical(getFullName(df), getFullName(cef)));
@@ -169,7 +169,7 @@ setMethodS3("fitOneArray", "SingleArrayUnitModel", function(this, array="remaini
   verbose && enter(verbose, "Fitting model");
   tFit <- processTime();
 
-  fit <- base::lapply(y, FUN=fitUnit);
+  fit <- lapply(y, FUN=fitUnit);
 
   timers$fit <- timers$fit + (processTime() - tFit);
   y <- NULL; # Not needed anymore (to minimize memory usage)
@@ -203,7 +203,7 @@ setMethodS3("fitOneArray", "SingleArrayUnitModel", function(this, array="remaini
     nunits <- length(units);
     # Get distribution of what is spend where
     timers$write <- timers$writePaf + timers$writeCes;
-    t <- base::lapply(timers, FUN=function(timer) unname(timer[3]));
+    t <- lapply(timers, FUN=function(timer) unname(timer[3]));
     t <- unlist(t);
     t <- 100 * t / t["total"];
     printf(verbose, "Fraction of time spent on different tasks: Fitting: %.1f%%, Reading: %.1f%%, Writing: %.1f%% (of which %.2f%% is for encoding/writing chip-effects), Explicit garbage collection: %.1f%%\n", t["fit"], t["read"], t["write"], 100*t["writeCes"]/t["write"], t["gc"]);
